pydeseq2.inference.Inference
=============================

.. currentmodule:: pydeseq2.inference

.. autoclass:: Inference

   .. rubric:: Methods

   .. autosummary::

      ~Inference.lin_reg_mu
      ~Inference.irls
      ~Inference.alpha_mle
      ~Inference.wald_test
      ~Inference.fit_rough_dispersions
      ~Inference.fit_moments_dispersions
      ~Inference.dispersion_trend_gamma_glm
      ~Inference.lfc_shrink_nbinom_glm
